@@ -182,6 +182,8 @@ class eamonn(object):
 
     @staticmethod
     def f2h(txt):  # fiddler转header
+        if isinstance(txt, dict):
+            return txt
         arr = txt.split("\n")
         headers = {}
         for i in arr:
@@ -550,6 +552,9 @@ class eamonn(object):
                 tmp_arr = []
             tmp_a = tmp_arr
         arc.append(tmp_a)
+        for index, i in enumerate(arc):
+            if not i:
+                arc.pop(index)
         return arc
 
     @staticmethod
